@@ -47,7 +47,8 @@ class Config(object):
                                  'limit_memory_consumption': None,
                                  'skip_ssl_validation': False,
                                  'autorestart': False,
-                                 'non_local_traffic': False},
+                                 'non_local_traffic': False,
+                                 'sub_collection_warn': 5},
                         'Api': {'is_enabled': False,
                                 'url': '',
                                 'project_name': '',
